@@ -184,7 +184,7 @@ class Insight_Definition:
 
     def __get_card_id(self):
 
-        url = self._base_url_askdata+"/smartfeed/agents/"+self.agent_id+"/insights/insightslug/"+self.slug
+        url = self._base_url_askdata+"/smartfeed/agents/"+self.agent_id+"/insight-slugs/"+self.slug
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
@@ -655,6 +655,7 @@ class Insight_Definition:
 
         return response.json()
 
+
     def get_component(self, component_id):
         for component in self.components:
             if (component["id"] == component_id):
@@ -743,11 +744,11 @@ class Insight_Definition:
         r = s.put(url=url, json=entity_settings, headers=headers)
         r.raise_for_status()
 
-    def add_to_channel(self, original_channel_id, new_channel_id):
-        url = self._base_url_askdata + "/smartfeed/pin/pinned/"+original_channel_id+"?addMode=true"
+    def add_to_channel(self, new_channel_id):
+        url = self._base_url_askdata + "/smartfeed/pin/pinned/"+new_channel_id+"?addMode=true"
         body = [
             {
-                "targetId": new_channel_id,
+                "targetId": self.definition_id,
                 "type": "CARD",
                 "pinnedValues": {}
             }
@@ -1307,28 +1308,27 @@ class Insight_Definition:
         r = s.get(url=get_url, headers=headers)
         r.raise_for_status()
         if(r.json()!=[]):
-            body = {
-                "role": "ADMIN",
-                "userId": r.json()[0]["id"]
-            }
-            try:
-                url = self.smart_insight_url+"/insights/"+self.definition_id+"/users"
-
-                s = requests.Session()
-                s.keep_alive = False
-                retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-                s.mount('https://', HTTPAdapter(max_retries=retries))
-
-                headers = {
-                    "Content-Type": "application/json",
-                    "Authorization": "Bearer" + " " + self._token
+            for user in r.json():
+                body = {
+                    "role": "ADMIN",
+                    "userId": user["id"]
                 }
-                query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-                #logging.info("URL {}".format(query_url))
-                r = s.post(url=url, json=body, headers=headers)
-                r.raise_for_status()
-            except:
-                logging.info("User {} can't be invited to channel, make sure the email is associated to an Askdata user".format(follower_email))
+                try:
+                    url = self.smart_insight_url+"/insights/"+self.definition_id+"/users"
+
+                    s = requests.Session()
+                    s.keep_alive = False
+                    retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+                    s.mount('https://', HTTPAdapter(max_retries=retries))
+
+                    headers = {
+                        "Content-Type": "application/json",
+                        "Authorization": "Bearer" + " " + self._token
+                    }
+                    r = s.post(url=url, json=body, headers=headers)
+                    r.raise_for_status()
+                except:
+                    logging.info("User {} can't be invited to channel, make sure the email is associated to an Askdata user".format(admin_email))
 
         else:
             logging.error("EMAIL ERRATA: Inserire una email corrispondente ad un utente Askdata")
@@ -1351,29 +1351,29 @@ class Insight_Definition:
         r = s.get(url=get_url, headers=headers)
         r.raise_for_status()
         if(r.json()!=[]):
-            body = {
-                "role": "FOLLOWER",
-                "userId": r.json()[0]["id"]
-            }
-            try:
-                url = self.smart_insight_url+"/insights/"+self.definition_id+"/users"
-
-                s = requests.Session()
-                s.keep_alive = False
-                retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-                s.mount('https://', HTTPAdapter(max_retries=retries))
-
-                headers = {
-                    "Content-Type": "application/json",
-                    "Authorization": "Bearer" + " " + self._token
+            for user in r.json():
+                body = {
+                    "role": "FOLLOWER",
+                    "userId": user["id"]
                 }
-                query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-                #logging.info("URL {}".format(query_url))
-                r = s.post(url=url, json=body, headers=headers)
-                r.raise_for_status()
-            except:
-                logging.info("User {} can't be invited to channel, make sure the email is associated to an Askdata user".format(follower_email))
+                try:
+                    url = self.smart_insight_url+"/insights/"+self.definition_id+"/users"
 
+                    s = requests.Session()
+                    s.keep_alive = False
+                    retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+                    s.mount('https://', HTTPAdapter(max_retries=retries))
+
+                    headers = {
+                        "Content-Type": "application/json",
+                        "Authorization": "Bearer" + " " + self._token
+                    }
+                    query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
+                    #logging.info("URL {}".format(query_url))
+                    r = s.post(url=url, json=body, headers=headers)
+                    r.raise_for_status()
+                except:
+                    logging.info("User {} can't be invited to channel, make sure the email is associated to an Askdata user".format(follower_email))
         else:
             logging.error("EMAIL ERRATA: Inserire una email corrispondente ad un utente Askdata")
 
